OC.L10N.register(
    "ownpad_lite",
    {
    "Document was shared" : "Dokumenti u nda",
    "User %s shared quick document %s with you." : "Përdoruesi %s ndau me ju dokumentin e shpejtë %s.",
    "My pad" : "Blloku im",
    "Settings" : "Rregullime",
    "Pad Title" : "Titull Blloku",
    "Open" : "Hape",
    "Share with" : "Ndajeni me",
    "Share" : "Ndaje",
    "Etherpad service URL" : "URL shërbimi Etherpad",
    "Username" : "Emër përdoruesi",
    "Save" : "Ruaje"
},
"nplurals=2; plural=(n != 1);");
